@@ -37,6 +37,7 @@ from mypy_boto3_kafka.type_defs import (
     DescribeConfigurationRevisionResponseTypeDef,
     EncryptionInfoTypeDef,
     GetBootstrapBrokersResponseTypeDef,
+    GetCompatibleKafkaVersionsResponseTypeDef,
     ListClusterOperationsResponseTypeDef,
     ListClustersResponseTypeDef,
     ListConfigurationRevisionsResponseTypeDef,
@@ -49,6 +50,7 @@ from mypy_boto3_kafka.type_defs import (
     UpdateBrokerCountResponseTypeDef,
     UpdateBrokerStorageResponseTypeDef,
     UpdateClusterConfigurationResponseTypeDef,
+    UpdateClusterKafkaVersionResponseTypeDef,
     UpdateMonitoringResponseTypeDef,
 )
 
@@ -75,14 +77,14 @@ class Exceptions:
 
 class KafkaClient:
     """
-    [Kafka.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client)
+    [Kafka.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.can_paginate)
         """
 
     def create_cluster(
@@ -100,49 +102,49 @@ class KafkaClient:
         Tags: Dict[str, str] = None,
     ) -> CreateClusterResponseTypeDef:
         """
-        [Client.create_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Client.create_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.create_cluster)
         """
 
     def create_configuration(
         self,
-        KafkaVersions: List[str],
         Name: str,
         ServerProperties: Union[bytes, IO],
         Description: str = None,
+        KafkaVersions: List[str] = None,
     ) -> CreateConfigurationResponseTypeDef:
         """
-        [Client.create_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Client.create_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.create_configuration)
         """
 
     def delete_cluster(
         self, ClusterArn: str, CurrentVersion: str = None
     ) -> DeleteClusterResponseTypeDef:
         """
-        [Client.delete_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Client.delete_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.delete_cluster)
         """
 
     def describe_cluster(self, ClusterArn: str) -> DescribeClusterResponseTypeDef:
         """
-        [Client.describe_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Client.describe_cluster documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.describe_cluster)
         """
 
     def describe_cluster_operation(
         self, ClusterOperationArn: str
     ) -> DescribeClusterOperationResponseTypeDef:
         """
-        [Client.describe_cluster_operation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Client.describe_cluster_operation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
         """
 
     def describe_configuration(self, Arn: str) -> DescribeConfigurationResponseTypeDef:
         """
-        [Client.describe_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Client.describe_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.describe_configuration)
         """
 
     def describe_configuration_revision(
         self, Arn: str, Revision: int
     ) -> DescribeConfigurationRevisionResponseTypeDef:
         """
-        [Client.describe_configuration_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Client.describe_configuration_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
         """
 
     def generate_presigned_url(
@@ -153,76 +155,83 @@ class KafkaClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
         """
 
     def get_bootstrap_brokers(self, ClusterArn: str) -> GetBootstrapBrokersResponseTypeDef:
         """
-        [Client.get_bootstrap_brokers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Client.get_bootstrap_brokers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        """
+
+    def get_compatible_kafka_versions(
+        self, ClusterArn: str = None
+    ) -> GetCompatibleKafkaVersionsResponseTypeDef:
+        """
+        [Client.get_compatible_kafka_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
         """
 
     def list_cluster_operations(
         self, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListClusterOperationsResponseTypeDef:
         """
-        [Client.list_cluster_operations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Client.list_cluster_operations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
         """
 
     def list_clusters(
         self, ClusterNameFilter: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListClustersResponseTypeDef:
         """
-        [Client.list_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Client.list_clusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_clusters)
         """
 
     def list_configuration_revisions(
         self, Arn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationRevisionsResponseTypeDef:
         """
-        [Client.list_configuration_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Client.list_configuration_revisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
         """
 
     def list_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationsResponseTypeDef:
         """
-        [Client.list_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Client.list_configurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_configurations)
         """
 
     def list_kafka_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListKafkaVersionsResponseTypeDef:
         """
-        [Client.list_kafka_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Client.list_kafka_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
         """
 
     def list_nodes(
         self, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListNodesResponseTypeDef:
         """
-        [Client.list_nodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Client.list_nodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_nodes)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.untag_resource)
         """
 
     def update_broker_count(
         self, ClusterArn: str, CurrentVersion: str, TargetNumberOfBrokerNodes: int
     ) -> UpdateBrokerCountResponseTypeDef:
         """
-        [Client.update_broker_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Client.update_broker_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.update_broker_count)
         """
 
     def update_broker_storage(
@@ -232,14 +241,25 @@ class KafkaClient:
         TargetBrokerEBSVolumeInfo: List[BrokerEBSVolumeInfoTypeDef],
     ) -> UpdateBrokerStorageResponseTypeDef:
         """
-        [Client.update_broker_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Client.update_broker_storage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         """
 
     def update_cluster_configuration(
         self, ClusterArn: str, ConfigurationInfo: ConfigurationInfoTypeDef, CurrentVersion: str
     ) -> UpdateClusterConfigurationResponseTypeDef:
         """
-        [Client.update_cluster_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Client.update_cluster_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        """
+
+    def update_cluster_kafka_version(
+        self,
+        ClusterArn: str,
+        CurrentVersion: str,
+        TargetKafkaVersion: str,
+        ConfigurationInfo: ConfigurationInfoTypeDef = None,
+    ) -> UpdateClusterKafkaVersionResponseTypeDef:
+        """
+        [Client.update_cluster_kafka_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
         """
 
     def update_monitoring(
@@ -251,7 +271,7 @@ class KafkaClient:
         LoggingInfo: LoggingInfoTypeDef = None,
     ) -> UpdateMonitoringResponseTypeDef:
         """
-        [Client.update_monitoring documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Client.update_monitoring documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Client.update_monitoring)
         """
 
     @overload
@@ -259,13 +279,13 @@ class KafkaClient:
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Paginator.ListClusterOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+        [Paginator.ListClusterOperations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+        [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListClusters)
         """
 
     @overload
@@ -273,7 +293,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Paginator.ListConfigurationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+        [Paginator.ListConfigurationRevisions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
         """
 
     @overload
@@ -281,7 +301,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Paginator.ListConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+        [Paginator.ListConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
         """
 
     @overload
@@ -289,11 +309,11 @@ class KafkaClient:
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Paginator.ListKafkaVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+        [Paginator.ListKafkaVersions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.17/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+        [Paginator.ListNodes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         """
